"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TaskTrigger = void 0;
var _types = require("../../../../types");
class TaskTrigger {
  constructor(taskCache) {
    this.taskCache = taskCache;
  }
  async execute(context, store) {
    const tasks = this.taskCache.getTasks();
    if (tasks.length === 0) {
      return;
    }
    for (const task of tasks) {
      try {
        await context.tasks.trigger({
          definition: _types.EntriesTask.DeleteTrashBinEntries,
          name: `Headless CMS - Delete Entries - ${task.modelId}`,
          parent: store.getTask(),
          input: {
            modelId: task.modelId,
            entryIds: task.entryIds
          }
        });
      } catch (error) {
        console.error(`Error triggering task for model ${task.modelId}:`, error);
      }
    }

    // Clear the cache after processing
    this.taskCache.clear();
  }
}
exports.TaskTrigger = TaskTrigger;

//# sourceMappingURL=TaskTrigger.js.map